@@ -59,6 +59,7 @@
 #include "checks/level1/qstring-left.h"
 #include "checks/level1/range-loop-detach.h"
 #include "checks/level1/range-loop-reference.h"
+#include "checks/level1/readlock-detaching.h"
 #include "checks/level1/returning-data-from-temporary.h"
 #include "checks/level1/rule-of-two-soft.h"
 #include "checks/level1/skipped-base-method.h"
@@ -223,6 +224,7 @@ void CheckManager::registerChecks()
     registerFixIt(1, "fix-range-loop-add-qasconst", "range-loop-detach");
     registerCheck(check<RangeLoopReference>("range-loop-reference", CheckLevel1, RegisteredCheck::Option_VisitsStmts));
     registerFixIt(1, "fix-range-loop-add-ref", "range-loop-reference");
+    registerCheck(check<ReadlockDetaching>("readlock-detaching", CheckLevel1, RegisteredCheck::Option_None));
     registerCheck(check<ReturningDataFromTemporary>("returning-data-from-temporary", CheckLevel1, RegisteredCheck::Option_VisitsStmts));
     registerCheck(check<RuleOfTwoSoft>("rule-of-two-soft", CheckLevel1, RegisteredCheck::Option_VisitsStmts));
     registerCheck(check<SkippedBaseMethod>("skipped-base-method", CheckLevel1, RegisteredCheck::Option_VisitsStmts));
