@@ -1,35 +1,21 @@
 /*
-  This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2015 Klarälvdalens Datakonsult AB a KDAB Group company info@kdab.com
+    SPDX-FileContributor: Sérgio Martins <sergio.martins@kdab.com>
 
-    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-    Author: Sérgio Martins <sergio.martins@kdab.com>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef CLAZY_FIXIT_UTILS_H
 #define CLAZY_FIXIT_UTILS_H
 
-#include <clang/Parse/Parser.h>
 #include <clang/Basic/TokenKinds.h>
+#include <clang/Parse/Parser.h>
 
 #include <string>
 #include <vector>
 
-namespace clang {
+namespace clang
+{
 class ASTContext;
 class FixItHint;
 class SourceManager;
@@ -41,8 +27,8 @@ class CXXMemberCallExpr;
 class Stmt;
 }
 
-namespace clazy {
-
+namespace clazy
+{
 /**
  * Replaces whatever is in range, with replacement
  */
@@ -62,7 +48,10 @@ void insertParentMethodCall(const std::string &method, clang::SourceRange range,
  * Transforms foo into method("literal"), by inserting "method(" at the beginning, and ')' at the end
  * Takes into account multi-token literals such as "foo""bar"
  */
-bool insertParentMethodCallAroundStringLiteral(const clang::ASTContext *context, const std::string &method, clang::StringLiteral *lt, std::vector<clang::FixItHint> &fixits);
+bool insertParentMethodCallAroundStringLiteral(const clang::ASTContext *context,
+                                               const std::string &method,
+                                               clang::StringLiteral *lt,
+                                               std::vector<clang::FixItHint> &fixits);
 
 /**
  * Returns the range this literal spans. Takes into account multi token literals, such as "foo""bar"
@@ -91,25 +80,22 @@ clang::SourceLocation locForEndOfToken(const clang::ASTContext *context, clang::
 /**
  * Transforms a call such as: foo("hello").bar() into baz("hello")
  */
-bool transformTwoCallsIntoOne(const clang::ASTContext *context, clang::CallExpr *foo, clang::CXXMemberCallExpr *bar,
-                              const std::string &baz, std::vector<clang::FixItHint> &fixits);
-
+bool transformTwoCallsIntoOne(const clang::ASTContext *context,
+                              clang::CallExpr *foo,
+                              clang::CXXMemberCallExpr *bar,
+                              const std::string &baz,
+                              std::vector<clang::FixItHint> &fixits);
 
 /**
  * Transforms a call such as: foo("hello").bar() into baz()
  * This version basically replaces everything from start to end with baz.
  */
-bool transformTwoCallsIntoOneV2(const clang::ASTContext *context, clang::CXXMemberCallExpr *bar,
-                                const std::string &baz, std::vector<clang::FixItHint> &fixits);
+bool transformTwoCallsIntoOneV2(const clang::ASTContext *context, clang::CXXMemberCallExpr *bar, const std::string &baz, std::vector<clang::FixItHint> &fixits);
 
-clang::FixItHint fixItReplaceWordWithWord(const clang::ASTContext *context, clang::Stmt *begin,
-                                          const std::string &replacement, const std::string &replacee);
+clang::FixItHint fixItReplaceWordWithWord(const clang::ASTContext *context, clang::Stmt *begin, const std::string &replacement, const std::string &replacee);
 
-std::vector<clang::FixItHint> fixItRemoveToken(const clang::ASTContext *context,
-                                               clang::Stmt *stmt,
-                                               bool removeParenthesis);
+std::vector<clang::FixItHint> fixItRemoveToken(const clang::ASTContext *context, clang::Stmt *stmt, bool removeParenthesis);
 
 }
 
 #endif
-
