@@ -68,12 +68,8 @@ protected:
                             clazy::OptionalFileEntryRef File,
                             clang::StringRef SearchPath,
                             clang::StringRef RelativePath,
-#if LLVM_VERSION_MAJOR >= 19
                             const clang::Module *SuggestedModule,
                             bool ModuleImported,
-#else
-                            const clang::Module *Imported,
-#endif
                             clang::SrcMgr::CharacteristicKind FileType) override;
 
 private:
