@@ -1,30 +1,16 @@
 /*
-    This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2016 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2016 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <clang/AST/Type.h>
 
-#include <vector>
 #include <string>
+#include <vector>
 
-namespace clang {
+namespace clang
+{
 class CXXMethodDecl;
 class CXXRecordDecl;
 class ClassTemplateSpecializationDecl;
@@ -56,8 +42,7 @@ clang::ClassTemplateSpecializationDecl *templateDecl(clang::Decl *decl);
  *
  * Example: For QList<Foo>, getTemplateArgumentTypeStr(decl, 0) would return "Foo"
  */
-std::string getTemplateArgumentTypeStr(clang::ClassTemplateSpecializationDecl*,
-                                       unsigned int index, const clang::LangOptions &lo, bool recordOnly = false);
+std::string getTemplateArgumentTypeStr(clang::ClassTemplateSpecializationDecl *, unsigned int index, const clang::LangOptions &lo, bool recordOnly = false);
 
 clang::QualType getTemplateArgumentType(clang::ClassTemplateSpecializationDecl *, unsigned int index);
 
