@@ -8,7 +8,6 @@
 
 #include "Utils.h"
 #include "HierarchyUtils.h"
-#include "SourceCompatibilityHelpers.h"
 #include "StmtBodyRange.h"
 #include "StringUtils.h"
 #include "clazy_stl.h"
@@ -368,7 +367,7 @@ static bool isArgOfFunc(T expr, FunctionDecl *fDecl, const VarDecl *varDecl, boo
         }
 
         if ((t->isReferenceType() || t->isPointerType()) && !t->getPointeeType().isConstQualified()) {
-            return true; // function receives non-const ref, so our foreach variable cant be const-ref
+            return true; // function receives non-const ref, so our foreach variable can't be const-ref
         }
     }
 
@@ -717,7 +716,7 @@ const CXXRecordDecl *Utils::recordForMemberCall(CXXMemberCallExpr *call, std::st
 bool Utils::isAscii(StringLiteral *lt)
 {
     // 'é' for some reason has isAscii() == true, so also call containsNonAsciiOrNull
-    return lt && clazy::isAscii(lt) && !lt->containsNonAsciiOrNull();
+    return lt && lt->isOrdinary() && !lt->containsNonAsciiOrNull();
 }
 
 bool Utils::isInDerefExpression(Stmt *s, ParentMap *map)
