@@ -95,12 +95,8 @@ void ClazyPreprocessorCallbacks::InclusionDirective(clang::SourceLocation HashLo
                                                     clazy::OptionalFileEntryRef File,
                                                     llvm::StringRef SearchPath,
                                                     llvm::StringRef RelativePath,
-#if LLVM_VERSION_MAJOR >= 19
                                                     const clang::Module *SuggestedModule,
                                                     bool ModuleImported,
-#else
-                                                    const clang::Module *Imported,
-#endif
                                                     clang::SrcMgr::CharacteristicKind FileType)
 {
     check->VisitInclusionDirective(HashLoc,
@@ -111,12 +107,8 @@ void ClazyPreprocessorCallbacks::InclusionDirective(clang::SourceLocation HashLo
                                    File,
                                    SearchPath,
                                    RelativePath,
-#if LLVM_VERSION_MAJOR >= 19
                                    SuggestedModule,
                                    ModuleImported,
-#else
-                                   Imported,
-#endif
                                    FileType);
 }
 
@@ -137,57 +129,57 @@ CheckBase::~CheckBase()
 
 void CheckBase::VisitStmt(Stmt *)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitDecl(Decl *)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitMacroExpands(const Token &, const SourceRange &, const clang::MacroInfo *)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitMacroDefined(const Token &)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitDefined(const Token &, const SourceRange &)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitIfdef(clang::SourceLocation, const clang::Token &)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitIfndef(SourceLocation, const Token &)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitIf(SourceLocation, SourceRange, clang::PPCallbacks::ConditionValueKind)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitElif(SourceLocation, SourceRange, clang::PPCallbacks::ConditionValueKind, SourceLocation)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitElse(SourceLocation, SourceLocation)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitEndif(SourceLocation, SourceLocation)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::VisitInclusionDirective(clang::SourceLocation,
@@ -199,12 +191,10 @@ void CheckBase::VisitInclusionDirective(clang::SourceLocation,
                                         llvm::StringRef,
                                         llvm::StringRef,
                                         const clang::Module *,
-#if LLVM_VERSION_MAJOR >= 19
                                         bool ModuleImported,
-#endif
                                         clang::SrcMgr::CharacteristicKind)
 {
-    // Overriden in derived classes
+    // Overridden in derived classes
 }
 
 void CheckBase::enablePreProcessorCallbacks()
