@@ -18,8 +18,6 @@
 #include <unordered_map>
 #include <vector>
 
-class ClazyContext;
-
 using namespace clang;
 
 DetachingBase::DetachingBase(const std::string &name, ClazyContext *context, Options options)
@@ -33,7 +31,7 @@ bool DetachingBase::isDetachingMethod(CXXMethodDecl *method, DetachingMethodType
         return false;
     }
 
-    CXXRecordDecl *record = method->getParent();
+    const CXXRecordDecl *record = method->getParent();
     if (!record) {
         return false;
     }
