@@ -91,12 +91,14 @@ void FullyQualifiedMocTypes::VisitDecl(clang::Decl *decl)
     }
 }
 
-static std::string resolveTemplateType(const clang::TemplateSpecializationType *ptr, LangOptions lo, bool checkElabType = true);
-static std::string getQualifiedNameOfType(const Type *ptr, const LangOptions &lo, bool checkElabType = true)
+std::string FullyQualifiedMocTypes::getQualifiedNameOfType(const Type *ptr, bool checkElabType) const
 {
     if (auto *elabType = dyn_cast<ElaboratedType>(ptr); elabType && checkElabType) {
         if (auto *specType = dyn_cast<TemplateSpecializationType>(elabType->getNamedType().getTypePtrOrNull()); specType && !ptr->getAs<TypedefType>()) {
-            return resolveTemplateType(specType, lo, false);
+            return resolveTemplateType(specType, false);
+        }
+        if (elabType->isEnumeralType() && elabType->getAs<EnumType>()) {
+            return elabType->getAs<EnumType>()->getDecl()->getQualifiedNameAsString();
         }
     }
     if (auto *typedefDecl = ptr->getAs<TypedefType>(); typedefDecl && typedefDecl->getDecl()) {
@@ -110,15 +112,15 @@ static std::string getQualifiedNameOfType(const Type *ptr, const LangOptions &lo
     } else if (auto recordDecl = ptr->getAsRecordDecl()) {
         return recordDecl->getQualifiedNameAsString();
     }
-    return QualType::getFromOpaquePtr(ptr).getAsString(lo);
+    return QualType::getFromOpaquePtr(ptr).getAsString(lo());
 }
 
 // In Qt5, the type would contain lots of unneeded parameters: QDBusPendingReply<bool, void, void, void, void, void, void, void>
 // Thus we need to do all of the shenanigans below
 // specType->getCanonicalTypeInternal().getAsString(m_astContext.getPrintingPolicy())
-static std::string resolveTemplateType(const clang::TemplateSpecializationType *ptr, LangOptions lo, bool checkElabType)
+std::string FullyQualifiedMocTypes::resolveTemplateType(const clang::TemplateSpecializationType *ptr, bool checkElabType) const
 {
-    std::string str = getQualifiedNameOfType(ptr, lo, checkElabType);
+    std::string str = getQualifiedNameOfType(ptr, checkElabType);
     str += "<";
     bool firstArg = true;
     for (auto arg : ptr->template_arguments()) { // We reconstruct the type with the explicitly specified template params
@@ -126,11 +128,17 @@ static std::string resolveTemplateType(const clang::TemplateSpecializationType *
             str += ", ";
         }
         firstArg = false;
-        QualType argType = arg.getAsType();
-        if (argType.isConstQualified()) {
-            str += "const ";
+        if (arg.getKind() == TemplateArgument::Expression) {
+            // std::bitset<int(8)>, here int(8) is an expression!
+            llvm::raw_string_ostream outputStream(str);
+            arg.print(m_astContext.getPrintingPolicy(), outputStream, true);
+        } else {
+            QualType argType = arg.getAsType();
+            if (argType.isConstQualified()) {
+                str += "const ";
+            }
+            str += getQualifiedNameOfType(argType.getTypePtr());
         }
-        str += getQualifiedNameOfType(argType.getTypePtr(), lo);
     }
     str += ">";
     return str;
@@ -141,18 +149,18 @@ bool FullyQualifiedMocTypes::typeIsFullyQualified(QualType t, std::string &quali
     qualifiedTypeName.clear();
     typeName.clear();
 
-    if (auto *ptr = t.getTypePtrOrNull(); ptr && ptr->isRecordType()) {
+    if (auto *ptr = t.getTypePtrOrNull(); ptr && (ptr->isRecordType() || ptr->isEnumeralType())) {
         typeName = clazy::name(t.getUnqualifiedType(), lo(), /*asWritten=*/true); // Ignore qualifiers like const here
         if (typeName == "QPrivateSignal") {
             return true;
         }
 
         if (auto specType = ptr->getAs<TemplateSpecializationType>(); specType && !ptr->getAs<TypedefType>()) {
-            qualifiedTypeName = resolveTemplateType(specType, lo());
+            qualifiedTypeName = resolveTemplateType(specType);
         } else if (auto recordDecl = ptr->getAsRecordDecl(); recordDecl && recordDecl->isInAnonymousNamespace()) {
             return true;
         } else {
-            qualifiedTypeName = getQualifiedNameOfType(ptr, lo());
+            qualifiedTypeName = getQualifiedNameOfType(ptr);
         }
         return qualifiedTypeName.empty() || typeName == qualifiedTypeName;
     }
