@@ -24,8 +24,6 @@
 
 #include <vector>
 
-class ClazyContext;
-
 using namespace clang;
 
 QGetEnv::QGetEnv(const std::string &name, ClazyContext *context)
@@ -48,7 +46,7 @@ void QGetEnv::VisitStmt(clang::Stmt *stmt)
         return;
     }
 
-    if (CXXRecordDecl *record = method->getParent(); !record || clazy::name(record) != "QByteArray") {
+    if (const CXXRecordDecl *record = method->getParent(); !record || clazy::name(record) != "QByteArray") {
         return;
     }
 
@@ -58,7 +56,7 @@ void QGetEnv::VisitStmt(clang::Stmt *stmt)
     }
 
     CallExpr *qgetEnvCall = calls.back();
-    if (FunctionDecl *func = qgetEnvCall->getDirectCallee(); !func || clazy::name(func) != "qgetenv") {
+    if (const FunctionDecl *func = qgetEnvCall->getDirectCallee(); !func || clazy::name(func) != "qgetenv") {
         return;
     }
 
