@@ -32,8 +32,18 @@ WritingToTemporary::WritingToTemporary(const std::string &name, ClazyContext *co
 
 static bool isDisallowedClass(const std::string &className)
 {
-    static const std::vector<std::string> disallowed =
-        {"QTextCursor", "QDomElement", "KConfigGroup", "QWebElement", "QScriptValue", "QTextLine", "QTextBlock", "QDomNode", "QJSValue", "QTextTableCell"};
+    static const std::vector<std::string> disallowed = {
+        "QTextCursor",
+        "QDomElement",
+        "KConfigGroup",
+        "QWebElement",
+        "QScriptValue",
+        "QTextLine",
+        "QTextBlock",
+        "QDomNode",
+        "QJSValue",
+        "QTextTableCell",
+    };
     return clazy::contains(disallowed, className);
 }
 
@@ -45,9 +55,10 @@ static bool isDisallowedMethod(const std::string &name)
 
 static bool isKnownType(const std::string &className)
 {
-    static const std::vector<std::string> types = {"QList",           "QVector",     "QMap",        "QHash",  "QString", "QSet",      "QByteArray", "QUrl",
-                                                   "QVarLengthArray", "QLinkedList", "QRect",       "QRectF", "QBitmap", "QVector2D", "QVector3D",  "QVector4D",
-                                                   "QSize",           "QSizeF",      "QSizePolicy", "QPoint", "QPointF", "QColor"};
+    static const std::vector<std::string> types = {
+        "QList",  "QVector", "QMap",      "QHash",     "QString",   "QSet",  "QByteArray", "QUrl",        "QVarLengthArray", "QLinkedList", "QRect",
+        "QRectF", "QBitmap", "QVector2D", "QVector3D", "QVector4D", "QSize", "QSizeF",     "QSizePolicy", "QPoint",          "QPointF",     "QColor",
+    };
 
     return clazy::contains(types, className);
 }
