@@ -18,13 +18,6 @@
 #include <string>
 #include <vector>
 
-class ClazyContext;
-namespace clang
-{
-class CXXMethodDecl;
-class Stmt;
-} // namespace clang
-
 /**
  * Finds places where you're calling non-const member functions on temporaries.
  *
