@@ -1,38 +1,18 @@
 /*
-  This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2018 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2018 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "ifndef-define-typo.h"
-#include "Utils.h"
-#include "HierarchyUtils.h"
 #include "QtUtils.h"
 #include "TypeUtils.h"
+#include "Utils.h"
 #include "levenshteindistance.h"
 
 #include <clang/AST/AST.h>
 
-#include <iostream>
-
 using namespace clang;
-using namespace std;
-
 
 IfndefDefineTypo::IfndefDefineTypo(const std::string &name, ClazyContext *context)
     : CheckBase(name, context)
@@ -65,8 +45,9 @@ void IfndefDefineTypo::VisitIfdef(SourceLocation, const Token &)
 
 void IfndefDefineTypo::VisitIfndef(SourceLocation, const Token &macroNameTok)
 {
-    if (IdentifierInfo *ii = macroNameTok.getIdentifierInfo())
+    if (IdentifierInfo *ii = macroNameTok.getIdentifierInfo()) {
         m_lastIfndef = static_cast<std::string>(ii->getName());
+    }
 }
 
 void IfndefDefineTypo::VisitIf(SourceLocation, SourceRange, PPCallbacks::ConditionValueKind)
@@ -89,21 +70,23 @@ void IfndefDefineTypo::VisitEndif(SourceLocation, SourceLocation)
     m_lastIfndef.clear();
 }
 
-void IfndefDefineTypo::maybeWarn(const string &define, SourceLocation loc)
+void IfndefDefineTypo::maybeWarn(const std::string &define, SourceLocation loc)
 {
-    if (m_lastIfndef == "Q_CONSTRUCTOR_FUNCTION") // Transform into a list if more false-positives need to be added
+    if (m_lastIfndef == "Q_CONSTRUCTOR_FUNCTION") { // Transform into a list if more false-positives need to be added
         return;
+    }
 
     if (define == m_lastIfndef) {
         m_lastIfndef.clear();
         return;
     }
 
-    if (define.length() < 4)
+    if (define.length() < 4) {
         return;
+    }
 
     const int levDistance = levenshtein_distance(define, m_lastIfndef);
     if (levDistance < 3) {
-        emitWarning(loc, string("Possible typo in define. ") + m_lastIfndef + " vs " + define);
+        emitWarning(loc, std::string("Possible typo in define. ") + m_lastIfndef + " vs " + define);
     }
 }
