@@ -1,43 +1,27 @@
 /*
-  This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2018 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2018 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "qt-keywords.h"
-#include "FixItUtils.h"
 #include "ClazyContext.h"
+#include "FixItUtils.h"
 #include "PreProcessorVisitor.h"
 #include "clazy_stl.h"
 
-#include <clang/Lex/MacroInfo.h>
 #include <clang/Basic/Diagnostic.h>
 #include <clang/Basic/IdentifierTable.h>
 #include <clang/Basic/SourceManager.h>
+#include <clang/Lex/MacroInfo.h>
 #include <clang/Lex/Token.h>
 #include <llvm/ADT/StringRef.h>
 
-#include <ctype.h>
 #include <algorithm>
+#include <ctype.h>
 #include <vector>
 
 using namespace clang;
-using namespace std;
 
 QtKeywords::QtKeywords(const std::string &name, ClazyContext *context)
     : CheckBase(name, context)
@@ -49,29 +33,33 @@ QtKeywords::QtKeywords(const std::string &name, ClazyContext *context)
 void QtKeywords::VisitMacroExpands(const Token &macroNameTok, const SourceRange &range, const clang::MacroInfo *minfo)
 {
     IdentifierInfo *ii = macroNameTok.getIdentifierInfo();
-    if (!ii || !minfo)
+    if (!ii || !minfo) {
         return;
-
-    if (auto ppvisitor = m_context->preprocessorVisitor) {
-        // Save some CPU cycles. No point in running if QT_NO_KEYWORDS
-        if (ppvisitor->isQT_NO_KEYWORDS())
-            return;
     }
 
-    static const vector<StringRef> keywords = { "foreach", "signals", "slots", "emit" };
+    if (auto *ppvisitor = m_context->preprocessorVisitor) {
+        // Save some CPU cycles. No point in running if QT_NO_KEYWORDS
+        if (ppvisitor->isQT_NO_KEYWORDS()) {
+            return;
+        }
+    }
+
+    static const std::vector<StringRef> keywords = {"foreach", "signals", "slots", "emit"};
     std::string name = static_cast<std::string>(ii->getName());
-    if (!clazy::contains(keywords, name))
+    if (!clazy::contains(keywords, name)) {
         return;
+    }
 
     // Make sure the macro is Qt's. It must be defined in Qt's headers, not 3rdparty
     std::string qtheader = static_cast<std::string>(sm().getFilename(sm().getSpellingLoc(minfo->getDefinitionLoc())));
-    if (!clazy::endsWith(qtheader, "qglobal.h") && !clazy::endsWith(qtheader, "qobjectdefs.h"))
+    if (!clazy::endsWithAny(qtheader, {"qglobal.h", "qobjectdefs.h", "qtmetamacros.h", "qforeach.h"})) {
         return;
+    }
 
     std::vector<FixItHint> fixits;
     std::string replacement = "Q_" + name;
     std::transform(replacement.begin(), replacement.end(), replacement.begin(), ::toupper);
     fixits.push_back(clazy::createReplacement(range, replacement));
 
-    emitWarning(range.getBegin(), "Using a Qt keyword (" + string(ii->getName()) + ")", fixits);
+    emitWarning(range.getBegin(), "Using a Qt keyword (" + std::string(ii->getName()) + ")", fixits);
 }
