@@ -9,17 +9,8 @@
 
 #include "checkbase.h"
 
-#include <clang/Basic/SourceLocation.h>
-
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class MacroInfo;
-class Token;
-} // namespace clang
-
 /**
  * See README-qt-keywords.md for more info.
  */
