@@ -158,7 +158,7 @@ bool replacementForQComboBox(clang::MemberExpr *membExpr, const std::string &fun
         message = "Using QComboBox::activated(const QString &). Use textActiated() instead";
         replacement = "textActivated";
     } else if (functionName == "highlighted") {
-        message = "Using QComboBox::hilighted(const QString &). Use textHighlighted() instead";
+        message = "Using QComboBox::highlighted(const QString &). Use textHighlighted() instead";
         replacement = "textHighlighted";
     } else {
         return false;
@@ -473,12 +473,7 @@ void Qt6DeprecatedAPIFixes::fixForDeprecatedOperator(Stmt *stmt, const std::stri
             }
             auto *uni = dyn_cast<UnaryOperator>(child);
             if (uni) {
-#if LLVM_VERSION_MAJOR >= 19
-#define STRING_EQUALS(a, b) a == b
-#else
-#define STRING_EQUALS(a, b) a.equals(b)
-#endif
-                if (STRING_EQUALS(clang::UnaryOperator::getOpcodeStr(uni->getOpcode()), "*")) {
+                if (clang::UnaryOperator::getOpcodeStr(uni->getOpcode()) == "*") {
                     isPointer = true;
                 }
             }
