@@ -30,12 +30,8 @@ public:
                                  clazy::OptionalFileEntryRef File,
                                  clang::StringRef SearchPath,
                                  clang::StringRef RelativePath,
-#if LLVM_VERSION_MAJOR >= 19
                                  const clang::Module *SuggestedModule,
                                  bool ModuleImported,
-#else
-                                 const clang::Module *Imported,
-#endif
                                  clang::SrcMgr::CharacteristicKind FileType) override;
     bool m_including_qcontainerfwd = false;
     std::set<clang::StringRef> m_qcontainerfwd_included_in_files;
