@@ -29,12 +29,8 @@ public:
                                  clazy::OptionalFileEntryRef File,
                                  clang::StringRef SearchPath,
                                  clang::StringRef RelativePath,
-#if LLVM_VERSION_MAJOR >= 19
                                  const clang::Module *SuggestedModule,
                                  bool ModuleImported,
-#else
-                                 const clang::Module *Imported,
-#endif
                                  clang::SrcMgr::CharacteristicKind FileType) override;
 };
 
