@@ -14,12 +14,6 @@
 
 #include <string>
 
-class ClazyContext;
-namespace clang
-{
-class Stmt;
-} // namespace clang
-
 /**
  * Detects when you're using QVariant::value<Foo>() instead of QVariant::toFoo().
  *
