@@ -12,19 +12,12 @@
 
 #include <string>
 
-class Caller;
-class ClazyContext;
-
 namespace clang
 {
 namespace ast_matchers
 {
 class MatchFinder;
 } // namespace ast_matchers
-class Stmt;
-class VarDecl;
-class CXXRecordDecl;
-class QualType;
 } // namespace clang
 
 class UnusedResultCheck : public CheckBase
