@@ -1,25 +1,10 @@
 /*
-    This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2015 Klarälvdalens Datakonsult AB a KDAB Group company info@kdab.com
+    SPDX-FileContributor: Sérgio Martins <sergio.martins@kdab.com>
 
-    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-    Author: Sérgio Martins <sergio.martins@kdab.com>
+    SPDX-FileCopyrightText: 2015 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2015 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "requiredresults.h"
@@ -74,7 +59,7 @@ bool RequiredResults::shouldIgnoreMethod(const StringRef &qualifiedName)
         "DOM::HTMLCollectionImpl::firstItem",
         "DOM::HTMLCollectionImpl::nextItem",
         "DOM::HTMLCollectionImpl::firstItem",
-        "ImapResourceBase::settings"
+        "ImapResourceBase::settings",
     };
 
     return clazy::contains(files, qualifiedName);
@@ -96,7 +81,7 @@ void RequiredResults::VisitStmt(clang::Stmt *stm)
             continue;
 
         std::string methodName = methodDecl->getQualifiedNameAsString();
-        if (shouldIgnoreMethod(StringRef(methodName.c_str()))) // Filter out some false positives
+        if (shouldIgnoreMethod(methodName)) // Filter out some false positives
             continue;
 
         QualType qt = methodDecl->getReturnType();
@@ -123,7 +108,7 @@ void RequiredResults::VisitStmt(clang::Stmt *stm)
 
         if (!bailout) {
             std::string error = std::string("Unused result of const member (") + methodName + ')';
-            emitWarning(clazy::getLocStart(callExpr), error.c_str());
+            emitWarning(callExpr->getBeginLoc(), error);
         }
     }
 }
