@@ -27,6 +27,8 @@ int main() { return 0; }
 
 #if QT_VERSION_MAJOR == 5
 #include "usingnamespace.qt5.moc_"
+#elif Q_MOC_OUTPUT_REVISION == 69
+#include "usingnamespace.qt6.moc_69"
 #else
 #include "usingnamespace.qt6.moc_"
 #endif
